Attn: Change mpipl target to crash@0 target

To start MPIPL we need to start obmc-host-crash@0.target (changed from
obmc-host-diagnostic-mode@0.target).

Signed-off-by: Ben Tyner <ben.tyner@ibm.com>
Change-Id: I41294357a3f08ea41b320a3b892045f6f0c81f78
diff --git a/attn/attn_common.cpp b/attn/attn_common.cpp
index ed21ba8..fce3d54 100644
--- a/attn/attn_common.cpp
+++ b/attn/attn_common.cpp
@@ -17,10 +17,10 @@
     // We will be transitioning host by starting appropriate dbus target
     std::string target = "obmc-host-quiesce@0.target"; // quiesce is default
 
-    // diagnostic mode state requested
-    if (HostState::Diagnostic == i_hostState)
+    // crash (mpipl) mode state requested
+    if (HostState::Crash == i_hostState)
     {
-        target = "obmc-host-diagnostic-mode@0.target";
+        target = "obmc-host-crash@0.target";
     }
 
     auto bus    = sdbusplus::bus::new_system();